@@ -5,7 +5,7 @@
 # require:
 #	postgresql-8.3.x
 #
-SRC_URI=http://pgfoundry.org/frs/download.php/2047/textsearch_ja-8.4.0.tar.gz
+SRC_URI=http://pgfoundry.org/frs/download.php/2186/textsearch_ja-8.4.1.tar.gz
 SRC_FILE=${SRC_URI##*/}
 PAC_NAME=${SRC_FILE%%.tar.gz}
 #VERSION=${PAC_NAME##*-}
@@ -21,7 +21,7 @@ SYS_NAME="${CPU}-${REL}"
 
 PLAMO=/expo/Build
 #SRC_DIR=$PLAMO/Archive/%category%
-PAC_DIR=$PLAMO/Packages/4.5.1a/09_webdb/01_PostgreSQL.tgz
+PAC_DIR=$PLAMO/Packages/4.6/09_webdb/01_PostgreSQL.tgz
 BUILD_DIR=$PLAMO/pgfoundry
 CUSTOM_DIR=$BUILD_DIR/Custom
 PAT_FILE=
@@ -78,7 +78,7 @@ mkdir -p work
 #%% end
 _EOF_
 
-tar cvfz ../${PAC_NAME}-i386-1.tgz  `find . -type f` 
+tar cvfz ../${PAC_NAME}.tgz  `find . -type f` 
 # opt/${POSTGRESQL} usr/share/doc/${PAC_NAME}/ install/doinst.sh
 
-mv -v ../${PAC_NAME}-i386-1.tgz  ${PAC_DIR}/${PAC_NAME}-${VERSION}-${SYS_NAME}.tgz
+mv -v ../${PAC_NAME}.tgz  ${PAC_DIR}/${PAC_NAME}-${VERSION}-${SYS_NAME}.tgz
